==> hlint-2.0.11-6-x86_64.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.0.11
id: hlint-2.0.11-JJtr3RMIXSyCw6eKu2KlOw
key: hlint-2.0.11-JJtr3RMIXSyCw6eKu2KlOw
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact CC Config.Compute Config.Haskell
                Config.Read Config.Type Config.Yaml HSE.All HSE.Match HSE.Reduce
                HSE.Scope HSE.Type HSE.Unify HSE.Util Hint.All Hint.Bracket
                Hint.Comment Hint.Duplicate Hint.Export Hint.Extensions Hint.Import
                Hint.Lambda Hint.List Hint.ListRec Hint.Match Hint.Monad
                Hint.Naming Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict
                Hint.Type Hint.Unsafe Hint.Util Test.All Test.Annotations
                Test.InputOutput Test.Proof Test.Translate Test.Util
abi: 61393942d06d7be6afd99e5e61988239
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hlint-2.0.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/hlint-2.0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.0.11-JJtr3RMIXSyCw6eKu2KlOw
depends:
    base-4.10.1.0 process-1.6.1.0 filepath-1.4.1.2 directory-1.3.0.2
    containers-0.5.10.2
    unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV
    yaml-0.8.25-ITsFqbq3blw7wAvfFQu3xZ
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj bytestring-0.10.8.2
    transformers-0.5.2.0 data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65
    cpphs-1.20.8-2BGd3s4rqvQIxc0obNJwmA
    cmdargs-0.10.18-6bkRWEoIaWqEtqIB64CQNf
    haskell-src-exts-1.19.1-6osooW3lbE1BgbYPFRxpEo
    haskell-src-exts-util-0.2.1.2-6r4zuiWRzlg2cwRSjwT4cL
    uniplate-1.6.12-KEBCAJdeJV5Cpdl7sQYF8W
    ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE
    extra-1.6.2-5lFfezp1NaeBeNWnWTrlJV
    refact-0.3.0.2-1c3LOFK0JsrLXZrmkaP3U7
    aeson-1.2.3.0-LNkLuLvRI8W9I8ocVQs80F
    hscolour-1.24.4-1Y3d0ngoISJ82bh0GSbJSM
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV=b12cdae8ac228affcce9703d4cef3dce
             yaml-0.8.25-ITsFqbq3blw7wAvfFQu3xZ=b88d937bb1f104871a5f73e518bc226f
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65=82f3b4ad59d56e7fb1579643899ebf63
             cpphs-1.20.8-2BGd3s4rqvQIxc0obNJwmA=e946109d15144e6d27ab9c4ca9dda096
             cmdargs-0.10.18-6bkRWEoIaWqEtqIB64CQNf=d2ead4026b00faa2638870c5a7f7348b
             haskell-src-exts-1.19.1-6osooW3lbE1BgbYPFRxpEo=cb2a6ec7ba5934be83d0a587eb139bd6
             haskell-src-exts-util-0.2.1.2-6r4zuiWRzlg2cwRSjwT4cL=7aea8c8302936d012dca8ab18436586a
             uniplate-1.6.12-KEBCAJdeJV5Cpdl7sQYF8W=0979fe64d448f3909eb4c4d33c81e6e0
             ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE=de59792f66ffb61bd5cb2ed7de76d387
             extra-1.6.2-5lFfezp1NaeBeNWnWTrlJV=042f057de6e28a9e2e3fe70aefde26e8
             refact-0.3.0.2-1c3LOFK0JsrLXZrmkaP3U7=bc07a58c6bbfa5fdad3a005400cb995d
             aeson-1.2.3.0-LNkLuLvRI8W9I8ocVQs80F=46287d49060ec1324ce6cfe2c348dbdf
             hscolour-1.24.4-1Y3d0ngoISJ82bh0GSbJSM=96a1f3f2f3f90df993807ce148e5c25f
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hlint-2.0.11-7-x86_64.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.0.11
id: hlint-2.0.11-BFpAo59gTq1COuhFNpOC8n
key: hlint-2.0.11-BFpAo59gTq1COuhFNpOC8n
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact CC Config.Compute Config.Haskell
                Config.Read Config.Type Config.Yaml HSE.All HSE.Match HSE.Reduce
                HSE.Scope HSE.Type HSE.Unify HSE.Util Hint.All Hint.Bracket
                Hint.Comment Hint.Duplicate Hint.Export Hint.Extensions Hint.Import
                Hint.Lambda Hint.List Hint.ListRec Hint.Match Hint.Monad
                Hint.Naming Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict
                Hint.Type Hint.Unsafe Hint.Util Test.All Test.Annotations
                Test.InputOutput Test.Proof Test.Translate Test.Util
abi: 25845c4a20326b17c80ffd85cb01f3ea
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hlint-2.0.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/hlint-2.0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.0.11-BFpAo59gTq1COuhFNpOC8n
depends:
    base-4.10.1.0 process-1.6.1.0 filepath-1.4.1.2 directory-1.3.0.2
    containers-0.5.10.2
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
    yaml-0.8.25-OccDXcEqSq27upU2wkbg0
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj bytestring-0.10.8.2
    transformers-0.5.2.0 data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65
    cpphs-1.20.8-Bhbe42uOQIYHMmx1XR4YFN
    cmdargs-0.10.18-6bkRWEoIaWqEtqIB64CQNf
    haskell-src-exts-1.19.1-BZeaHhmzJaBBBpRWYqrwzp
    haskell-src-exts-util-0.2.1.2-79r5byrGJ0bJqOTUF2dAUC
    uniplate-1.6.12-RJKX4rwKpxeNd3JFWGD2
    ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE
    extra-1.6.2-5lFfezp1NaeBeNWnWTrlJV
    refact-0.3.0.2-1c3LOFK0JsrLXZrmkaP3U7
    aeson-1.2.3.0-D2GZ8DOS25VDM6QP4cWx4T
    hscolour-1.24.4-1Y3d0ngoISJ82bh0GSbJSM
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=8c4e411a71da620d885f29fab6ff998d
             yaml-0.8.25-OccDXcEqSq27upU2wkbg0=a174a981fcc7f9289d14d76fae7c549a
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65=82f3b4ad59d56e7fb1579643899ebf63
             cpphs-1.20.8-Bhbe42uOQIYHMmx1XR4YFN=a9ffd13402621f0cdd89c524b85f3003
             cmdargs-0.10.18-6bkRWEoIaWqEtqIB64CQNf=d2ead4026b00faa2638870c5a7f7348b
             haskell-src-exts-1.19.1-BZeaHhmzJaBBBpRWYqrwzp=9e7d1f47a4d57e9fb92fbdd8cc305af5
             haskell-src-exts-util-0.2.1.2-79r5byrGJ0bJqOTUF2dAUC=34e47950bc78f2c65e9e5ac9a00e0ece
             uniplate-1.6.12-RJKX4rwKpxeNd3JFWGD2=ae21a83d47e14db81d98074d23de7330
             ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE=de59792f66ffb61bd5cb2ed7de76d387
             extra-1.6.2-5lFfezp1NaeBeNWnWTrlJV=042f057de6e28a9e2e3fe70aefde26e8
             refact-0.3.0.2-1c3LOFK0JsrLXZrmkaP3U7=bc07a58c6bbfa5fdad3a005400cb995d
             aeson-1.2.3.0-D2GZ8DOS25VDM6QP4cWx4T=39ae635650efd3973e415ab038ded489
             hscolour-1.24.4-1Y3d0ngoISJ82bh0GSbJSM=96a1f3f2f3f90df993807ce148e5c25f
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
